<%!
from misc.config import HOST, SITE_SLOGO
%>\
<!doctype html>\
<head>\
<meta charset="utf-8">\
<link rel="stylesheet" href="${css.init|n}" type="text/css">\
<script src="${js.init|n}"></script>\
${self.html_head()}\
<title>${self.html_title()} - ${HOST}</title>\
</head>\
<body>${next.body()}${self.html_foot()}</body>\
<%def name="html_title()">${SITE_SLOGO}</%def>\
<%def name="html_head()"></%def>\
<%def name="html_foot()"></%def>\
