<%!
from misc.config import HOST, SITE_SLOGO
import httplib
%>
<!doctype html>\
<head>\
<meta charset="utf-8">\
<title>${status_code} : ${httplib.responses[status_code]} - ${HOST}</title>\
</head>\

<body>
<div style="width:900px;margin:50px auto 0">
%if status_code == 404:
<p>这是一个不存在的地方</p>
<p><a href="/">点击这里 , 返回首页</a><p>
%else:
    <div>貌似出岔子了 , <a href="/">点此返回首页</a>...</div>
    <div style="margin-top:32px">出错细节</div>
    %if status_code == 500:
    <div>
    <pre>${traceback}</pre>
    <pre>${pformat(environ)}</pre>
    </div>
    %else:
    <div>
    <pre>${log_message}</pre>
    </div>
    %endif
%endif
</div>
</body>
