#coding:utf-8
import _env
from misc.config import HOST


APP_INSTALL = [] 

#from view import blog
#APP_INSTALL.append(
#    (
#        HOST,
#        (
#            blog, 
#        )
#    )
#)
#
#from view import vps
#APP_INSTALL.append(
#    (
#        "vps.%s"%HOST,
#        (
#            vps, 
#        )
#    )
#)
#
#from view import user
#APP_INSTALL.append(
#   (
#       ".*",
#       (app.user)
#   )
#)
